# $Id: /local/CPAN/Mango/trunk/t/lib/Mango/Test/Meta.pm 1959 2007-08-10T05:27:29.884596Z claco  $
package Mango::Test::Meta;
use strict;
use warnings;

BEGIN {
    use base qw/Mango::Object::Meta/;
};

1;